@@ -5,7 +5,7 @@ https://developers.meethue.com/documentation/error-messages
 
 
 class AiohueException(Exception):
-    """Base error for aiohue."""
+    """Base exception for aiohue."""
 
 
 class Unauthorized(AiohueException):
@@ -16,10 +16,19 @@ class LinkButtonNotPressed(AiohueException):
     """Raised when trying to create a user but link button not pressed."""
 
 
+class InvalidEvent(AiohueException):
+    """Raised when we receive an event that we can not (yet) handle."""
+
+
+class InvalidAPIVersion(AiohueException):
+    """Raised when we're trying to connect to an unsupported bridge version."""
+
+
 ERRORS = {1: Unauthorized, 101: LinkButtonNotPressed}
 
 
-def raise_error(error):
-    type = error["type"]
+def raise_from_error(error: dict):
+    """Raise Exception based on Hue error."""
+    type = error.get("type")
     cls = ERRORS.get(type, AiohueException)
-    raise cls("{}: {}".format(type, error["description"]))
+    raise cls(error["description"])
